pub fn estimate_baseline(
binary_image: &GrayImage,
line_bbox: &BoundingBox,
) -> BaselineEstimateExpand description
Estimate baseline for a text line using bottom pixel analysis
This implements Tesseract’s approach of finding the bottom edge of characters and fitting a curve to them.